@@ -215,12 +215,12 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setExternalClusterMode()
         return self
 
-    def setCloudName(self, value):
-        self._jconf.setCloudName(value)
+    def setCloudName(self, cloudName):
+        self._jconf.setCloudName(cloudName)
         return self
 
-    def setNthreads(self, value):
-        self._jconf.setNthreads(value)
+    def setNthreads(self, numThreads):
+        self._jconf.setNthreads(numThreads)
         return self
 
     def setReplEnabled(self):
@@ -247,8 +247,8 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setModelPrintAfterTrainingDisabled()
         return self
 
-    def setDefaultNumReplSessions(self, value):
-        self._jconf.setDefaultNumReplSessions(value)
+    def setDefaultNumReplSessions(self, numSessions):
+        self._jconf.setDefaultNumReplSessions(numSessions)
         return self
 
     def setClusterTopologyListenerEnabled(self):
@@ -275,20 +275,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFailOnUnsupportedSparkParamDisabled()
         return self
 
-    def setJks(self, value):
-        self._jconf.setJks(value)
+    def setJks(self, path):
+        self._jconf.setJks(path)
         return self
 
-    def setJksPass(self, value):
-        self._jconf.setJksPass(value)
+    def setJksPass(self, password):
+        self._jconf.setJksPass(password)
         return self
 
-    def setJksAlias(self, value):
-        self._jconf.setJksAlias(value)
+    def setJksAlias(self, alias):
+        self._jconf.setJksAlias(alias)
         return self
 
-    def setSslCACert(self, value):
-        self._jconf.setSslCACert(value)
+    def setSslCACert(self, path):
+        self._jconf.setSslCACert(path)
         return self
 
     def setHashLoginEnabled(self):
@@ -315,20 +315,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberosLoginDisabled()
         return self
 
-    def setLoginConf(self, value):
-        self._jconf.setLoginConf(value)
+    def setLoginConf(self, filePath):
+        self._jconf.setLoginConf(filePath)
         return self
 
-    def setUserName(self, value):
-        self._jconf.setUserName(value)
+    def setUserName(self, username):
+        self._jconf.setUserName(username)
         return self
 
-    def setPassword(self, value):
-        self._jconf.setPassword(value)
+    def setPassword(self, password):
+        self._jconf.setPassword(password)
         return self
 
-    def setSslConf(self, value):
-        self._jconf.setSslConf(value)
+    def setSslConf(self, path):
+        self._jconf.setSslConf(path)
         return self
 
     def setAutoFlowSslEnabled(self):
@@ -339,32 +339,32 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setAutoFlowSslDisabled()
         return self
 
-    def setLogLevel(self, value):
-        self._jconf.setLogLevel(value)
+    def setLogLevel(self, level):
+        self._jconf.setLogLevel(level)
         return self
 
-    def setLogDir(self, value):
-        self._jconf.setLogDir(value)
+    def setLogDir(self, dir):
+        self._jconf.setLogDir(dir)
         return self
 
-    def setBackendHeartbeatInterval(self, value):
-        self._jconf.setBackendHeartbeatInterval(value)
+    def setBackendHeartbeatInterval(self, interval):
+        self._jconf.setBackendHeartbeatInterval(interval)
         return self
 
-    def setCloudTimeout(self, value):
-        self._jconf.setCloudTimeout(value)
+    def setCloudTimeout(self, timeout):
+        self._jconf.setCloudTimeout(timeout)
         return self
 
-    def setNodeNetworkMask(self, value):
-        self._jconf.setNodeNetworkMask(value)
+    def setNodeNetworkMask(self, mask):
+        self._jconf.setNodeNetworkMask(mask)
         return self
 
-    def setStacktraceCollectorInterval(self, value):
-        self._jconf.setStacktraceCollectorInterval(value)
+    def setStacktraceCollectorInterval(self, interval):
+        self._jconf.setStacktraceCollectorInterval(interval)
         return self
 
-    def setContextPath(self, value):
-        self._jconf.setContextPath(value)
+    def setContextPath(self, contextPath):
+        self._jconf.setContextPath(contextPath)
         return self
 
     def setFlowScalaCellAsyncEnabled(self):
@@ -375,28 +375,28 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFlowScalaCellAsyncDisabled()
         return self
 
-    def setMaxParallelScalaCellJobs(self, value):
-        self._jconf.setMaxParallelScalaCellJobs(value)
+    def setMaxParallelScalaCellJobs(self, limit):
+        self._jconf.setMaxParallelScalaCellJobs(limit)
         return self
 
-    def setInternalPortOffset(self, value):
-        self._jconf.setInternalPortOffset(value)
+    def setInternalPortOffset(self, offset):
+        self._jconf.setInternalPortOffset(offset)
         return self
 
-    def setBasePort(self, value):
-        self._jconf.setBasePort(value)
+    def setBasePort(self, port):
+        self._jconf.setBasePort(port)
         return self
 
-    def setMojoDestroyTimeout(self, value):
-        self._jconf.setMojoDestroyTimeout(value)
+    def setMojoDestroyTimeout(self, timeoutInMilliseconds):
+        self._jconf.setMojoDestroyTimeout(timeoutInMilliseconds)
         return self
 
-    def setExtraProperties(self, value):
-        self._jconf.setExtraProperties(value)
+    def setExtraProperties(self, extraProperties):
+        self._jconf.setExtraProperties(extraProperties)
         return self
 
-    def setFlowExtraHttpHeaders(self, value):
-        self._jconf.setFlowExtraHttpHeaders(value)
+    def setFlowExtraHttpHeaders(self, *args):
+        self._jconf.setFlowExtraHttpHeaders(*args)
         return self
 
     def setFlowProxyRequestMaxSize(self, value):
@@ -423,16 +423,16 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInsecureXGBoostDenied()
         return self
 
-    def setFlowDir(self, value):
-        self._jconf.setFlowDir(value)
+    def setFlowDir(self, dir):
+        self._jconf.setFlowDir(dir)
         return self
 
-    def setClientIp(self, value):
-        self._jconf.setClientIp(value)
+    def setClientIp(self, ip):
+        self._jconf.setClientIp(ip)
         return self
 
-    def setClientWebPort(self, value):
-        self._jconf.setClientWebPort(value)
+    def setClientWebPort(self, port):
+        self._jconf.setClientWebPort(port)
         return self
 
     def setClientVerboseEnabled(self):
@@ -443,20 +443,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientVerboseDisabled()
         return self
 
-    def setClientNetworkMask(self, value):
-        self._jconf.setClientNetworkMask(value)
+    def setClientNetworkMask(self, mask):
+        self._jconf.setClientNetworkMask(mask)
         return self
 
-    def setClientFlowBaseurlOverride(self, value):
-        self._jconf.setClientFlowBaseurlOverride(value)
+    def setClientFlowBaseurlOverride(self, baseUrl):
+        self._jconf.setClientFlowBaseurlOverride(baseUrl)
         return self
 
-    def setClientCheckRetryTimeout(self, value):
-        self._jconf.setClientCheckRetryTimeout(value)
+    def setClientCheckRetryTimeout(self, timeout):
+        self._jconf.setClientCheckRetryTimeout(timeout)
         return self
 
-    def setVerifySslCertificates(self, value):
-        self._jconf.setVerifySslCertificates(value)
+    def setVerifySslCertificates(self, verify):
+        self._jconf.setVerifySslCertificates(verify)
         return self
 
     def setSslHostnameVerificationInInternalRestConnectionsEnabled(self):
@@ -483,26 +483,26 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberizedHiveDisabled()
         return self
 
-    def setHiveHost(self, value):
-        self._jconf.setHiveHost(value)
+    def setHiveHost(self, host):
+        self._jconf.setHiveHost(host)
         return self
 
-    def setHivePrincipal(self, value):
-        self._jconf.setHivePrincipal(value)
+    def setHivePrincipal(self, principal):
+        self._jconf.setHivePrincipal(principal)
         return self
 
-    def setHiveJdbcUrlPattern(self, value):
-        self._jconf.setHiveJdbcUrlPattern(value)
+    def setHiveJdbcUrlPattern(self, pattern):
+        self._jconf.setHiveJdbcUrlPattern(pattern)
         return self
 
-    def setHiveToken(self, value):
-        self._jconf.setHiveToken(value)
+    def setHiveToken(self, token):
+        self._jconf.setHiveToken(token)
         return self
 
-    def setIcedDir(self, value):
-        self._jconf.setIcedDir(value)
+    def setIcedDir(self, dir):
+        self._jconf.setIcedDir(dir)
         return self
 
-    def setRestApiTimeout(self, value):
-        self._jconf.setRestApiTimeout(value)
+    def setRestApiTimeout(self, timeout):
+        self._jconf.setRestApiTimeout(timeout)
         return self
