@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OAutoML import H2OAutoML
 
@@ -53,6 +53,11 @@ class H2OAutoMLRegressor(H2OAutoML):
                  keepCrossValidationModels=False,
                  keepCrossValidationFoldAssignment=False,
                  exportCheckpointsDir=None,
+                 distribution="AUTO",
+                 tweediePower=1.5,
+                 quantileAlpha=0.5,
+                 huberAlpha=0.9,
+                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
