@@ -4,9 +4,11 @@ import functools as ft
 import h2o
 from h2o.utils.typechecks import assert_is_type
 from ._base import _fetch_state, _fetch_leaderboard
-from ._estimator import H2OAutoML  # keep this to link the estimator for backwards compatibility in module imports
+from ._estimator import H2OAutoML
 from ._output import H2OAutoMLOutput
 
+__all__ = ['H2OAutoML', 'get_automl', 'get_leaderboard']
+
 
 def get_automl(project_name):
     """
@@ -23,6 +25,7 @@ def get_leaderboard(aml, extra_columns=None):
     """
     Retrieve the leaderboard from the AutoML instance.
     Contrary to the default leaderboard attached to the automl instance, this one can return columns other than the metrics.
+    
     :param H2OAutoML aml: the instance for which to return the leaderboard.
     :param extra_columns: a string or a list of string specifying which optional columns should be added to the leaderboard. Defaults to None.
         Currently supported extensions are:
@@ -31,7 +34,9 @@ def get_leaderboard(aml, extra_columns=None):
         - 'predict_time_per_row_ms`: column providing the average prediction time by the model for a single row.
         - 'algo': column providing the algorithm name for each model.
     :return: An H2OFrame representing the leaderboard.
+    
     :examples:
+    
     >>> aml = H2OAutoML(max_runtime_secs=30)
     >>> aml.train(y=y, training_frame=train)
     >>> lb_all = h2o.automl.get_leaderboard(aml, 'ALL')
